@@ -29,7 +29,7 @@ snCoord = [SkyCoord(14.162*u.deg, -9.90253*u.deg, frame='icrs'), \
 # run the association algorithm!
 # this first checks the GHOST database for a SN by name, then by coordinates, and
 # if we have no match then it manually associates them.
-hosts = getTransientHosts(snName, snCoord, verbose=verbose, starcut='normal', ascentMatch=True, px=64)
+hosts = getTransientHosts(snName, snCoord, verbose=verbose, starcut='normal', ascentMatch=True, px=64, savepath='/Users/agagliano/Downloads/testGHOSTPath/')
 
 # classify transients
 hosts_wPredictions = classify(hosts)
@@ -86,5 +86,5 @@ coneSearchPairs(supernovaCoord[0], 1.e3)
 
 #7. Beta: find photometric redshift of host galaxies matches:
 from astro_ghost.photoz_helper import calc_photoz
-hosts = calc_photoz(hosts)
+posterior_dict, hosts = calc_photoz(hosts)
 print(hosts['photo_z'].values)
